@@ -36,7 +36,10 @@ class GraphLoader():
         if filename:
             nx.write_adjlist(self.G.to_directed(), filename)
             self.graph_handle = filename
-            hdfs.copyToHDFS(filename, filename)
+            hdfs.mkdir(filename)
+            hdfs.copyToHDFS(filename, filename+"/page_rank")
+            hdfs.copyToHDFS(filename, filename+"/shortest_path")
+            hdfs.copyToHDFS(filename, filename+"/degree")
         else:
             if self.graph_handle:
                 nx.write_adjlist(self.G.to_directed(), self.graph_handle)
