@@ -187,7 +187,9 @@ def bfs(G, source, name=None):
 def parallel_degree(hdfs_handle):
     '''Compute node degree in parallel for the graph adjacency list stored in hdfs_handle.'''
     hdfs.rm("pdegree")
-    hadoop_call = hdmc.build_generic_hadoop_call("Degree_mapper.py", "Degree_reducer.py", hdfs_handle+"/degree", "pdegree", [])
+    base_path =  os.path.realpath( __file__ ).split("/")
+    base_path = "/".join(base_path[0:-1])
+    hadoop_call = hdmc.build_generic_hadoop_call(base_path+"/Degree_mapper.py", base_path+"/Degree_reducer.py", hdfs_handle+"/degree", "pdegree", [])
     hdmc.execute_and_wait(hadoop_call)
     # copy the output to the input
     hdfs.rm(hdfs_handle+"/degree/part*")
@@ -201,7 +203,9 @@ def parallel_degree(hdfs_handle):
 def parallel_bfs(source, hdfs_handle, old_inf_count):
     '''Compute shortest path from source to all nodes in parallel for the graph adjacency list stored in hdfs_handle.'''
     hdfs.rm("PBFS-src-"+str(source))
-    hadoop_call = hdmc.build_generic_hadoop_call("PBFS_mapper.py", "PBFS_reducer.py", hdfs_handle+"/shortest_path/"+source, "PBFS-src-"+str(source), ["pbfs_source"])
+    base_path =  os.path.realpath( __file__ ).split("/")
+    base_path = "/".join(base_path[0:-1])
+    hadoop_call = hdmc.build_generic_hadoop_call(base_path+"/PBFS_mapper.py", base_path+"/PBFS_reducer.py", hdfs_handle+"/shortest_path/"+source, "PBFS-src-"+str(source), ["pbfs_source"])
     hdmc.execute_and_wait(hadoop_call)
     listing = hdfs.ls("PBFS-src-"+str(source)+"/part*")["stdout"].rstrip().split("\n")
     inf_count = 0
