@@ -5,4 +5,5 @@ Created on Sep 2, 2010
 '''
 import hdmc
 from hdmc import hdfs
-from . import util
+import util
+__author__ = "D. McClary (dan.mcclary@northwestern.edu)"
